summary refs log tree commit diff
diff options
context:
space:
mode:
authorLudovic Courtès <ludo@gnu.org>2013-03-28 15:30:27 +0100
committerLudovic Courtès <ludo@gnu.org>2013-03-29 00:16:58 +0100
commit3f5a932eeaa8111b841de64b742b1cc408f2419a (patch)
tree60dbbc700eb48e516cccade600df9c7153488249
parentf9bbf2a819d2b6fb3d56e289f8d8debc19e87a1a (diff)
downloadguix-3f5a932eeaa8111b841de64b742b1cc408f2419a.tar.gz
snix: Adjust import to current Nixpkgs input attribute names.
* guix/snix.scm (snix-derivation->guix-package): Use the new names
  `nativeBuildInputs' and `propagatedNativeBuildInputs'.
-rw-r--r--guix/snix.scm11
1 files changed, 7 insertions, 4 deletions
diff --git a/guix/snix.scm b/guix/snix.scm
index 3a470b9b8b..0c19fecb28 100644
--- a/guix/snix.scm
+++ b/guix/snix.scm
@@ -277,7 +277,7 @@ ATTRIBUTE is true, only that attribute is considered."
              %nix-instantiate "--strict" "--eval-only" "--xml"
 
              ;; Pass a dummy `crossSystem' argument so that `buildInputs' and
              ;; `buildNativeInputs' are not coalesced.
              ;; XXX: This is hacky and has other problems.
              ;"--arg" "crossSystem" cross-system
 
@@ -423,12 +423,15 @@ location of DERIVATION."
              (build-system gnu-build-system)
 
              ;; When doing a native Nixpkgs build, `buildInputs' is empty and
              ;; everything is in `buildNativeInputs'.  So we can't distinguish
              ;; between both, here.
+             ;;
+             ;; Note that `nativeBuildInputs' was renamed from
+             ;; `buildNativeInputs' in Nixpkgs sometime around March 2013.
              ,@(maybe-inputs 'inputs
-                             (convert-inputs "buildNativeInputs"))
+                             (convert-inputs "nativeBuildInputs"))
              ,@(maybe-inputs 'propagated-inputs
-                             (convert-inputs "propagatedBuildNativeInputs"))
+                             (convert-inputs "propagatedNativeBuildInputs"))
 
              (home-page ,(and=> (find-attribute-by-name "homepage" meta)
                                 attribute-value))
@@ -277,7 +277,7 @@ ATTRIBUTE is true, only that attribute is considered."
 
              ;; Pass a dummy `crossSystem' argument so that `buildInputs' and
-             ;; `buildNativeInputs' are not coalesced.
+             ;; `nativeBuildInputs' are not coalesced.
              ;; XXX: This is hacky and has other problems.
              ;"--arg" "crossSystem" cross-system
@@ -423,12 +423,15 @@ location of DERIVATION."
 
              ;; When doing a native Nixpkgs build, `buildInputs' is empty and
-             ;; everything is in `buildNativeInputs'.  So we can't distinguish
+             ;; everything is in `nativeBuildInputs'.  So we can't distinguish
              ;; between both, here.